crystal_toolkit.components.transformations.slab module — Crystal Toolkit documentation

# crystal_toolkit.components.transformations.slab module

class crystal_toolkit.components.transformations.slab.SlabTransformationComponent(input_structure_component_id: str, *args, **kwargs)

  Bases: `TransformationComponent`

  property description
  options_layouts(state=None, structure=None)

    Return a layout to change the transformation options (that is, that controls the args and kwargs that will be passed to pymatgen).

    The “state” option is so that the controls can be populated appropriately using existing args and kwargs, e.g. when restoring the control panel from a previous state.

    Parameters

      state – existing state in format {“args”: [], “kwargs”: {}}

    Returns

  property title
  property transformation